@@ -32,6 +32,7 @@ from .line import (
     current_from_import_import,
 )
 
+import fnmatch
 import os
 import sys
 import warnings
@@ -48,6 +49,12 @@ else:
 
 # The cached list of all known modules
 modules = set()
+# List of stored paths to compare against so that real paths are not repeated
+# handles symlinks not mount points
+paths = set()
+# Patterns to skip
+# TODO: This skiplist should be configurable.
+skiplist = (".git", ".config", ".local", ".share", "node_modules")
 fully_loaded = False
 
 
@@ -137,6 +144,10 @@ def find_modules(path):
     if not os.path.isdir(path):
         # Perhaps a zip file
         return
+    basepath = os.path.basename(path)
+    if any(fnmatch.fnmatch(basepath, entry) for entry in skiplist):
+        # Path is on skiplist
+        return
 
     try:
         filenames = os.listdir(path)
@@ -147,7 +158,10 @@ def find_modules(path):
         finder = importlib.machinery.FileFinder(path)
 
     for name in filenames:
-        if not any(name.endswith(suffix) for suffix in SUFFIXES):
+        if any(fnmatch.fnmatch(name, entry) for entry in skiplist):
+            # Path is on skiplist
+            continue
+        elif not any(name.endswith(suffix) for suffix in SUFFIXES):
             # Possibly a package
             if "." in name:
                 continue
@@ -190,9 +204,12 @@ def find_modules(path):
             continue
         else:
             if is_package:
-                for subname in find_modules(pathname):
-                    if subname != "__init__":
-                        yield "%s.%s" % (name, subname)
+                path_real = os.path.realpath(pathname)
+                if path_real not in paths:
+                    paths.add(path_real)
+                    for subname in find_modules(pathname):
+                        if subname != "__init__":
+                            yield "%s.%s" % (name, subname)
             yield name
 
 
